@@ -249,6 +249,10 @@ sub SanityCheck {
       }
     }
   }
+  if (-f "MANIFEST") {
+    use ExtUtils::Manifest qw(manicheck);
+    &manicheck;
+  }
 }
 
 # Set variables.
@@ -268,6 +272,7 @@ sub Vars {
   print CS "Export qw( env name ver installbin installlib installarch installman1 installman3);\n";
   # Use current plibs, if we have them.
   print CS "use lib \'./plib\';\n" if (-d "plib");
+  print CS "use lib \'./.AutoCons\';\n" if (-d ".AutoCons");
   # Variables.
   print CS "\$name = \"$name\";\n";
   print CS "\$ver  = \"$ver\";\n";
@@ -285,7 +290,7 @@ sub Vars {
   print CS "use AutoCons::AC;\n";
   # Construction environment.
   print CS "\$env = new cons(
-  CC            => \'@ echo [CC] %>;$Config{cc}\',
+  CC            => \'$Config{cc}\',
   CFLAGS        => \'$Config{ccflags}\',
   AR            => \'$Config{ar}\',
   LD            => \'$Config{ld}\',
@@ -349,6 +354,8 @@ sub Targs {
   print CS "\";\n";
   &DirCleanUp;
   if (-d "plib") {
+    print CS "# XS targets.\n";
+    &XSTargs;
     print CS "# Library targets.\n";
     &PLibTargs;
   }
@@ -379,13 +386,42 @@ sub Targs {
     my $l1 = <CH>;
     if ($l1 =~ /\/\* Generated by (.+) \*\//) {
       print CS "# Regenerate Config.h.\n";
-      print CS "Command \$env \"Config.h\", \"$1\", \"$^X $1\";\n";
+      Targ("Command", "Config.h", "$1", "$^X $1");
     }
   }
 }
 
 =pod
 
+* XSTargs()
+
+Add targets for testing.
+ TestTargs( )
+
+=cut
+
+sub XSTargs {
+  &DirSearch("plib");
+  foreach (@dirs) {
+    &DirSearch("$_");
+  }
+  foreach my $file (@files) {
+    next if ($file =~ /\.consign$/);
+    next if ($file !~ /\.xs/);
+    my $cfile = $file;
+    $cfile =~ s/\.xs/.c/;
+    my $ofile = $file;
+    $ofile =~ s/\.xs/$Config{_o}/;
+    print CS "Command \$env \"blib/$cfile\", \"$file\", \"xsubpp $file >blib/$cfile\";\n";
+    print CS "Objects \$env \"blib/$cfile\";\n";
+    my $instfile = $ofile;
+    $instfile =~ s/plib\///;
+    print CS "InstallAs \$env \"\$installarch/$instfile\", \"blib/$ofile\";\n";
+  }
+}
+
+=pod
+
 * TestTargs()
 
 Add targets for testing.
@@ -394,13 +430,9 @@ Add targets for testing.
 =cut
 
 sub TestTargs {
-  &DirSearch("t");
-  foreach (@files) {
-    next if ($_ !~ /^(.+)\.t$/);
-    print CS "# Test targets.
-Command \$env \"$_.tested\", \"$_\",\"@ [perl] require Test::Harness;Test::Harness::runtests(\\\"$_\\\")
-@ touch $_.tested\";\n";
-  }
+  print CS "# Test targets.\n";
+  my @ts = <t/*.t>;
+  print CS "Command \$env \"t/.tested\", qw(@ts), \"@ [perl] require Test::Harness;Test::Harness::runtests(<t/*.t>)\n  @ touch t/.tested\"\n";
 }
 
 =pod
@@ -419,8 +451,9 @@ sub PLibTargs {
   }
   foreach my $file (@files) {
     next if ($file =~ /\.consign$/);
+    next if ($file !~ /\.pm/);
     print CS "Cp \$env \"blib/$file\", \"$file\";\n";
-    $instfile = $file;
+    my $instfile = $file;
     $instfile =~ s/plib\///;
     print CS "InstallAs \$env \"\$installlib/$instfile\", \"blib/$file\";\n";
     push @ppods,"$file";
@@ -444,7 +477,7 @@ sub BinTargs {
   foreach my $file (@files) {
     next if ($file =~ /\.consign$/);
     print CS "Cp \$env \"blib/$file\", \"$file\";\n";
-    $instfile = $file;
+    my $instfile = $file;
     $instfile =~ s/bin\///;
     print CS "InstallAs \$env \"\$installbin/$instfile\", \"blib/$file\";\n";
     push @ppods,"$file";
@@ -467,7 +500,7 @@ sub PScriptTargs {
   foreach my $file (@files) {
     next if ($file =~ /\.consign$/);
     print CS "Cp \$env \"blib/$file\", \"$file\";\n";
-    $instfile = $file;
+    my $instfile = $file;
     $instfile =~ s/pscripts\///;
     print CS "InstallAs \$env \"\$installbin/$instfile\", \"blib/$file\";\n";
     push @ppods,"$file";
